# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2021-04-08)
### Feature
* **optimizr:** Update semver ([`6418afa`](https://github.com/joeriddles/optimizr/commit/6418afa26ecad105f5daabf49ad087e37e208fe1))

## v0.0.1 (2021-04-08)
### Fix
* **1.0.11:** Trying to get semantic_release to work ([`52c2e3f`](https://github.com/joeriddles/optimizr/commit/52c2e3f0935871bdf27d0d26b59f36c0a5d0c6e9))
